DaemonApiException class

Stable public error exposed by DaemonClient.

Callers should use code for control flow instead of depending on Dio or the daemon's JSON error envelope.

Implemented types

Constructors

DaemonApiException({required String code, required String message, required bool retryable, int? statusCode, String? requestId, Object? details, Object? cause})
const
DaemonApiException.fromDio(DioException error)
factory
DaemonApiException.fromResponse({required int? statusCode, required Object? body, Object? cause})
factory
DaemonApiException.fromSseRequest(SseRequestException error)
factory

Properties

cause Object?
final
code String
final
details Object?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
requestId String?
final
retryable bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited