Config class

Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

Config({required String version, Server? server, Log? log, bool autoRestore = false})
Config.fromJson(Map<String, dynamic> json)
factory

Properties

autoRestore bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
log Log?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
server Server?
getter/setter pair
version String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited