PullDownloadDto class
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Constructors
- PullDownloadDto({required String stage, int? downloadedBytes, int? totalBytes, int? percent, String? digest})
-
PullDownloadDto.fromJson(Map<
String, dynamic> json) -
factory
Properties
- digest ↔ String?
-
getter/setter pair
- downloadedBytes ↔ int?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- percent ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stage ↔ String
-
getter/setter pair
- totalBytes ↔ int?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited