ServerArtifactDto class

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Constructors

ServerArtifactDto({required String digest, int? size, String? mediaType, ServerPlatformDto? platform, DateTime? verifiedAt, required int referenceCount})
ServerArtifactDto.fromJson(Map<String, dynamic> json)
factory
ServerArtifactDto.fromModel(ServerModel model)
factory

Properties

digest String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mediaType String?
getter/setter pair
platform ServerPlatformDto?
getter/setter pair
referenceCount int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
getter/setter pair
verifiedAt DateTime?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited