ServerSourceDto class

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Constructors

ServerSourceDto({String kind = 'import', String? registry, required String namespace, required String name, required String version, String? versionDigest, String? artifactId, String? artifactDigest, String? artifactMediaType, String? builtinBundleFamily, String? builtinBundleId, String? builtinKey})
ServerSourceDto.fromJson(Map<String, dynamic> json)
factory
ServerSourceDto.fromModel(ServerModel model)
factory

Properties

artifactDigest String?
getter/setter pair
artifactId String?
getter/setter pair
artifactMediaType String?
getter/setter pair
builtinBundleFamily String?
getter/setter pair
builtinBundleId String?
getter/setter pair
builtinKey String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
kind String
getter/setter pair
name String
getter/setter pair
namespace String
getter/setter pair
registry String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
getter/setter pair
versionDigest String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited