ToolDto class

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Constructors

ToolDto({required String id, required String alias, required String host, required int port, required String status, String? serverId, ToolServerDto? server, String? materializedArtifactDigest, String? contentState})
ToolDto.fromJson(Map<String, dynamic> json)
factory
ToolDto.fromModel(ToolModel tool, {ServerModel? server})
factory

Properties

alias String
getter/setter pair
contentState String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
host String
getter/setter pair
id String
getter/setter pair
materializedArtifactDigest String?
getter/setter pair
port int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
server ToolServerDto?
getter/setter pair
serverId String?
getter/setter pair
status String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited