ToolLifecycleEventDto class

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Constructors

ToolLifecycleEventDto({required String type, required String reason, required ToolDto tool, required DateTime occurredAt})
ToolLifecycleEventDto.fromJson(Map<String, dynamic> json)
factory
ToolLifecycleEventDto.fromModel(ToolLifecycleEventModel model)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
occurredAt DateTime
getter/setter pair
reason String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tool ToolDto
getter/setter pair
type String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited