ToolServerDto class
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Constructors
- ToolServerDto({required String namespace, required String name, required String version})
- ToolServerDto.fromIdentity(ServerIdentity identity)
-
factory
-
ToolServerDto.fromJson(Map<
String, dynamic> json) -
factory
- ToolServerDto.fromModel(ServerModel server)
-
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited