ToolWithApiKeyDto class
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Constructors
- ToolWithApiKeyDto({required String id, required String alias, required String host, required int port, required String apiKey, required String status, String? serverId, ToolServerDto? server, String? materializedArtifactDigest, String? contentState})
-
ToolWithApiKeyDto.fromJson(Map<
String, dynamic> json) -
factory
- ToolWithApiKeyDto.fromModel(ToolModel tool, {ServerModel? server})
-
factory
Properties
- alias ↔ String
-
getter/setter pair
- apiKey ↔ String
-
getter/setter pair
- contentState ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- host ↔ String
-
getter/setter pair
- id ↔ String
-
getter/setter pair
- materializedArtifactDigest ↔ String?
-
getter/setter pair
- port ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- server ↔ ToolServerDto?
-
getter/setter pair
- serverId ↔ String?
-
getter/setter pair
- status ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited