opentool_daemon_utils library

Classes

CommandUtil
CryptoUtil
DaemonLogger
DirectoryUtil
EventData
ExecutionContext
Represents the runtime context used for variable expansion.
Instruction
InstructNameType
JsonFileUtil
OpentoolfileParser
Main parser and interpreter for Opentoolfile. It parses the file into a flat list of instructions and builds a contextual environment for variable expansion.
SseClient
SudoPlatformContext
SudoTokenPayload
SudoUtil
SystemUtil
ZipInspection
ZipUtil

Enums

LogModule

Properties

logger DaemonLogger
getter/setter pair

Functions

findAvailablePort(String host, int startPort) Future<int>
Returns the first available port on host starting from startPort. Continues incrementing the port number until a free socket is found.
isPortAvailable(String host, int port) Future<bool>