CommandUtil class

Constructors

CommandUtil()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

runCommand(String workDir, String command) Future<String>
runStream(String workDir, String command, List<String> args, {void onStdout(String command, String output)?, void onStderr(String command, String output)?, bool printStd = true}) Future<int>