DirectoryUtil class

Constructors

DirectoryUtil()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

copyAndRenameFile(String sourcePath, String targetPath) Future<void>
copyDirectory(Directory source, Directory destination) Future<void>
deleteDirectory(String dirPath) Future<void>
deleteFile(String filePath) Future<void>
getBaseDir() String
getParentDir(String filePath) String
getUserHomeDir() String