Instruction class

Constructors

Instruction(String name, List<String> args, int line, {String? blockComment, String? inlineComment})

Properties

args List<String>
final
blockComment String?
final
hashCode int
The hash code for this object.
no setterinherited
inlineComment String?
final
line int
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited