OpentoolfileParser class

Main parser and interpreter for Opentoolfile. It parses the file into a flat list of instructions and builds a contextual environment for variable expansion.

Constructors

OpentoolfileParser(String source)
Constructor: parse and interpret the given Opentoolfile source.

Properties

context ExecutionContext
Execution context after interpretation.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getArgs() Map<String, String>
getCmd() List<String>
getEntrypoint() String?
getEnvs() Map<String, String>
getFinalCommand() List<String>
getRun() List<String>
getWorkdir() String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited