SseClient class

Constructors

SseClient({required String baseUrl, Map<String, String>? headers, String? apiKey})

Properties

apiKey String?
getter/setter pair
baseUrl String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request(String path, {Map<String, dynamic>? requestBody, Map<String, dynamic>? queryParameters, String method = 'POST', Map<String, String>? headers}) Future<Stream<String>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(String data, void onEvent(String event, Map<String, dynamic> data)) → void