ZipUtil class
Constructors
- ZipUtil()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
archivePath(
String sourcePath, String entityPath, {Context? context}) → String -
inspect(
String zipFilePath) → Future< ZipInspection> -
unzipToTemp(
String zipFilePath) → Future< String> -
zipDirectory(
String sourceDirPath, String zipFilePath) → Future< void>
Constants
- maxArchiveEntries → const int
- maxManifestSize → const int
- maxUncompressedSize → const int