OpenToolServerDto class
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Constructors
- OpenToolServerDto({int schemaVersion = 2, required String id, required String alias, required String registry, required String namespace, required String version, required String name, ServerSourceDto? source, ServerPlatformDto? platform, int? size, DateTime? createdAt, ServerArtifactDto? artifact, ServerPolicyDto? policy, ServerCapabilitiesDto? capabilities, String? state})
-
OpenToolServerDto.fromJson(Map<
String, dynamic> json) -
factory
- OpenToolServerDto.fromModel(ServerModel model)
-
factory
Properties
- alias ↔ String
-
getter/setter pair
- artifact ↔ ServerArtifactDto?
-
getter/setter pair
- capabilities ↔ ServerCapabilitiesDto?
-
getter/setter pair
- createdAt ↔ DateTime?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pair
- name ↔ String
-
getter/setter pair
- namespace ↔ String
-
getter/setter pair
- platform ↔ ServerPlatformDto?
-
getter/setter pair
- policy ↔ ServerPolicyDto?
-
getter/setter pair
- registry ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion ↔ int
-
getter/setter pair
- size ↔ int?
-
getter/setter pair
- source ↔ ServerSourceDto?
-
getter/setter pair
- state ↔ String?
-
getter/setter pair
- version ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited