OpenToolServerDto class

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Constructors

OpenToolServerDto({required String id, required String alias, required String registry, required String repo, required String name, required String tag})
OpenToolServerDto.fromJson(Map<String, dynamic> json)
factory
OpenToolServerDto.fromModel(ServerModel model)
factory

Properties

alias String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
name String
getter/setter pair
registry String
getter/setter pair
repo String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited