VersionDto class
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Constructors
-
VersionDto({required String name, required String version, int apiVersion = 2, List<
String> capabilities = const []}) -
VersionDto.fromJson(Map<
String, dynamic> json) -
factory
- VersionDto.fromModel(VersionModel model)
-
factory
Properties
- apiVersion ↔ int
-
getter/setter pair
-
capabilities
↔ List<
String> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited