ExecutionContext class
Represents the runtime context used for variable expansion.
Constructors
Properties
-
args
→ Map<
String, String> -
final
-
cmd
↔ List<
String> -
getter/setter pair
- entrypoint ↔ String?
-
getter/setter pair
-
envs
→ Map<
String, String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- workdir ↔ String
-
getter/setter pair
Methods
-
expand(
String value) → String -
Expand variables like
$VARusing ARG/ENV definitions. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited